@@ -186,7 +186,11 @@
 #define ELF_TARG_MACH	EM_SPARCV9
 #define ELF_TARG_CLASS	ELFCLASS64
 #else
+#if defined(__sparc_v9__) || defined(__sparcv9)
+#define ELF_TARG_MACH	EM_SPARC32PLUS
+#else
 #define ELF_TARG_MACH	EM_SPARC
+#endif
 #define ELF_TARG_CLASS	ELFCLASS32
 #endif
 #define ELF_TARG_DATA	ELFDATA2MSB
@@ -221,7 +225,11 @@
 
 #elif defined(__or1k__)
 
+#if defined(EM_OPENRISC)
 #define ELF_TARG_MACH	EM_OPENRISC
+#else
+#define ELF_TARG_MACH	EM_OR1K
+#endif
 #define ELF_TARG_CLASS	ELFCLASS32
 #define ELF_TARG_DATA	ELFDATA2MSB
 
